body {
	padding-top: 40px;
	padding-bottom: 40px;
	background-color: #222233;
}
.logo {
	max-width: 200px;
	padding: 19px 29px 29px;
	margin: 0 auto 20px;
}
.form-signin {
	max-width: 300px;
	padding: 19px 29px 29px;
	margin: 0 auto 20px;
	background-color: #fff;
	border: 1px solid #e5e5e5;
	-webkit-border-radius: 5px;
	-moz-border-radius: 5px;
	border-radius: 5px;
	-webkit-box-shadow: 0 1px 2px rgba(0,0,0,.05);
	-moz-box-shadow: 0 1px 2px rgba(0,0,0,.05);
	box-shadow: 0 1px 2px rgba(0,0,0,.05);
}
.form-signin input[type="text"],
.form-signin input[type="password"] {
	font-size: 16px;
	height: auto;
	margin-bottom: 0;
	padding: 7px 9px;
}
.form-signin div.input-wrapper {
	margin-bottom: 15px;
}
.form-signin div.input-wrapper > * {
    display: block;
    width: 100%;
    -webkit-box-sizing: border-box;
       -moz-box-sizing: border-box;
            box-sizing: border-box;
}
.form-signin div.input-wrapper > ul.errorlist {
	background: #FFC4C4;
	border: 1px solid #C20000;
	margin: 0;
}
.form-signin div.input-wrapper > ul.errorlist li {
	list-style: none;
	padding: 5px;
	font-size: 0.9em;
}
.form-actions {
	margin: 0px;
}
