body {
	padding-bottom: 40px;
}

ul.no-style {
	list-style-type: none;
}

.menu.span12 {
	background-color: #222233;
	border-bottom: 1px solid #4D4C4C;
}

.logo-tsuru {
	max-width: 100px;
	padding: 13px 13px 13px;
	display: inline-block;
}

.drop {
	display: inline-block;
	float: right;
	position: relative;
	right: 35px;
	top: 15px;
}

.userbar {
	margin: 0 !important;
	background-color: #222233;
	opacity: 0.9;
}

.content {
	margin: 0 !important;
}

.sidebar .nav {
	margin-top: 10px;
}

.sidebar .nav > li {
	min-width: 90px;
}

.sidebar .nav > li.active > a {
	background: none repeat scroll 0 0 #222233;
	color: #fff;
}

.sidebar .nav > li > a {
	color: #fff;
	font-size: 13px;
}

.sidebar .nav > li > a:hover {
	background-color: transparent;
	font-weight: bold;
}

.sidebar .nav > .active {
	font-weight: bold;
}

.dropdown-menu {
	position: absolute;
	right: 10px;
	left: inherit;
}

.dropdown-toggle:focus {
	outline: 0 none;
}

select {
	width: 125px;
	margin-bottom: 20px;
}

.admin-menu {
	color: #fff;
	border-top: 3px solid #fff;
}

.report-issue {
	color: #fff;
	position: absolute;
	bottom: 55px;
	padding-left: 40px;
}

.report-issue a {
	color: #fff;
	text-decoration: none;
}

.span10.app-teams {
	padding-bottom: 5px;
}

.table th, .table td {
	vertical-align: middle;
}

.pager {
	padding-top: 20px;
	padding-left: 40px;
}

.pager .page a {
	border: 3px solid #bbbbbb;
	margin-left: 1px;
	margin-right: 1px;
	padding-left: 4px;
	padding-right: 4px;
	text-decoration: none;
	color: #000000;
}

.pager .current {
	  border: 3px solid #444444;
	  margin-left: 2px;
	  margin-right: 2px;
	  padding-left: 2px;
}

.text-right-important {
	text-align: right !important;
}

.search {
    margin-top: 20px;
}
