{% load staticfiles %}
<!DOCTYPE html>
<html lang="en">
	<head>
		<title>tsuru web dashboard</title>
		<meta charset="UTF-8" />
		<meta name="description" content="tsuru web dashboard">
		<meta name="viewport" content="width=device-width, initial-scale=1.0" />
        <link rel="stylesheet" href="{% static "css/bootstrap.min.css" %}">
        <link rel="stylesheet" href="{% static "css/bootstrap-responsive.min.css" %}">
        <link rel="stylesheet" href="{% static "css/abyss.css" %}">
        <link rel="icon" type="image/x-icon" href="{% static "img/favicon.ico" %}">
		{% block extra_css %}
		{% endblock extra_css %}
	</head>
	<body>
		<div class="row-fluid">
			<div class="menu span12">
				<div class="logo-tsuru">
                    <img src="{% static "img/brand.svg" %}">
				</div>
				<div class="drop">
					<a data-toggle="dropdown" class="dropdown-toggle" href="#">
						<i class="icon-cog icon-white"></i>
					</a>
					<ul class="dropdown-menu">
						<li><a href="{% url 'key' %}">Add keys</a></li>
						<li class="divider"></li>
						<li><a href="{% url 'change-password' %}">Change password</a></li>
						<li><a href="{% url 'logout' %}">Logout</a></li>
					</ul>
				</div>
			</div>
			<div class="userbar span12">
				{% block sidebar %}
				{% include "sidebar.html" %}
				{% endblock %}
			</div>
			<div class="content span12">
				<div class="container-fluid">
					<div class="row-fluid">
					    {% block header %}{% endblock %}
					</div>
				</div>
				{% include "messages.html" %}
				{% block content %}
				{% endblock %}
			</div>
		</div>
        <script src="{% static "js/jquery.min.js" %}"></script>
        <script src="{% static "js/bootstrap.min.js" %}"></script>
		{% block extra_js %}
		{% endblock %}
	</body>
</html>
