.search input {
  border: 1px solid #ccc;
  border-radius: 0;
  width: 95%;
  padding: 8px;
  float: left;
}

.search a {
  float: right;
  margin: 1px 5px 0 0;
}

i.icono-plus {
  color: #999;
}

.loader {
  clear: both;
}

.table {
    clear: both;
}
