.deploys th, .deploys td {
    text-align: left;
}

.deploys td.app {
    word-break: break-word;
    word-wrap: break-word;
}

.deploys .to-right {
    text-align: right;
}

#fileselect {
    display: block;
}

#filedrag {
    display: block;
    font-weight: bold;
    text-align: center;
    padding: 1em 0;
    margin: 1em 0;
    color: #555;
    border: 2px dashed #555;
    border-radius: 7px;
    cursor: default;
}

#filedrag.hover {
    color: #f00;
    border-color: #f00;
    border-style: solid;
    box-shadow: inset 0 3px 4px #888;
}

#output {
    color: #fff;
    background-color: #333;
    border-radius: 3px;
    padding: 10px 20px;
    position: relative;
    min-height: 15px;
}

#output img {
    position: absolute;
    right: 10px;
    top: 10px;
}
