{% extends "base.html" %}

{% block header %}
<h1>Run Commands</h1>
{% endblock %}

{% block content %}
<div class="container-fluid">
  <div class="row-fluid">
    <div class="span12">
      <form action="" method="post">
        {% csrf_token %}
        <fieldset>
          <div class="clearfix control-group{% if form.errors.app %} error{% endif %}">
            <label for="{{ app_form.app.name }}">App</label>
            <input type="text" class="input-xlarge" name="{{ form.app.name }}" id="autocomplete" value="{{ form.app.value|default:"" }}">
            <span class="help-inline">{{ form.errors.app }}</span>
          </div>
          <div class="clearfix control-group{% if form.errors.command %} error{% endif %}">
              <label>command</label>
              <textarea class="input-xxlarge" name="{{ form.command.name }}" rows=8></textarea>
              <span class="help-inline">{{ form.errors.command }}</span>
          </div>
          <button class="btn primary" type="submit">Run</button>
        </fieldset>
      </form>
    </div>
  </div>
</div>
{% endblock %}
