{% extends "base.html" %}

{% block header %}
<h1>Team add</h1>
{% endblock %}

{% block content %}
<div class="container-fluid">
	<div class="row-fluid">
		<div class="span12">
			<form action="" method="post">
				{% csrf_token %}
				<fieldset>
					<div class="clearfix control-group{% if form.errors.name %} error{% endif %}">
						<label>name</label>
						<input type="text" name="{{ form.name.name }}">
						<span class="help-inline">{{ form.errors.name }}</span>
					</div>
					<button class="btn primary" type="submit">Create</button>
				</fieldset>
			</form>
		</div>
	</div>
</div>
{% endblock content %}
