{% extends "apps/base.html" %}

{% block navbar %}
    {% include "apps/navbar.html" with active="autoscale" %}
{% endblock %}

{% block app-content %}
<div class="container-fluid">
	<div class="row-fluid">
		<div class="span12">
			<iframe src="{{ service_url }}" width="100%" height="1000" frameborder="0" marginheight="0" marginwidth="0">
		    </iframe>
		</div>
	</div>
</div>
{% endblock %}
