{% extends "base.html" %}

{% block sidebar %}
{% include "sidebar.html" with active="teams" %}
{% endblock %}

{% block header %}
<div class="btn-group pull-right">
	<a class="btn" title="Create Team" href="{% url 'team-add' %}"><i class="icon-plus"></i></a>
</div>
<h1>Teams</h1>
{% endblock %}

{% block content %}
<div class="container-fluid">
	<div class="row-fluid">
		<ul class="span12 teams unstyled">
			{% for team in teams %}
                <li><a data-team-name="{{ team.name }}" href="{% url 'team-info' team.name %}">{{ team.name }}</a></li>
			{% endfor %}
		</ul>
	</div>
</div>
{% endblock %}
