{% if messages %}
<div class="container-fluid">
	<div class="row-fluid">
		<div class="span12">
			{% for message in messages %}
			<div class="alert{% if message.tags %} alert-{{ message.tags }}{% endif %}">
				{{ message }}
			</div>
			{% endfor %}
		</div>
	</div>
</div>
{% endif %}
